# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bixo/listings/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bixo/listings/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bixo\\Listings\\": "packages/bixo/listings/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bixo\Listings\Providers\ListingsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Listings'  => Bixo\Listings\Facades\Listings::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bixo\\ListingsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bixo\Listings\Providers\ListingsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bixo\Listings\Providers\ListingsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bixo\Listings\Providers\ListingsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/listings/{modulename}

**User**

    http://path-to-route-folder/user/listings/{modulename}

**Public**

    http://path-to-route-folder/listings


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/listings/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/listings/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/listings/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/listings/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/listings/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/listings/{modulename}/{slug}
    METHOD: GET