<?php

namespace Bixo\Listings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Listings\Models\Listing;

class ListingPolicy
{

    /**
     * Determine if the given user can view the listing.
     *
     * @param UserPolicy $user
     * @param Listing $listing
     *
     * @return bool
     */
    public function view(UserPolicy $user, Listing $listing)
    {
        if ($user->canDo('listings.listing.view') && $user->isAdmin()) {
            return true;
        }

        return $listing->user_id == user_id() && $listing->user_type == user_type();
    }

    /**
     * Determine if the given user can create a listing.
     *
     * @param UserPolicy $user
     * @param Listing $listing
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('listings.listing.create');
    }

    /**
     * Determine if the given user can update the given listing.
     *
     * @param UserPolicy $user
     * @param Listing $listing
     *
     * @return bool
     */
    public function update(UserPolicy $user, Listing $listing)
    {
        if ($user->canDo('listings.listing.edit') && $user->isAdmin()) {
            return true;
        }

        return $listing->user_id == user_id() && $listing->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given listing.
     *
     * @param UserPolicy $user
     * @param Listing $listing
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Listing $listing)
    {
        return $listing->user_id == user_id() && $listing->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given listing.
     *
     * @param UserPolicy $user
     * @param Listing $listing
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Listing $listing)
    {
        if ($user->canDo('listings.listing.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given listing.
     *
     * @param UserPolicy $user
     * @param Listing $listing
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Listing $listing)
    {
        if ($user->canDo('listings.listing.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
