<?php

namespace Bixo\Listings\Providers;

use Illuminate\Support\ServiceProvider;

class ListingsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'listings');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'listings');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerListings();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerListings()
    {
        $this->app->bind('listings', function($app) {
            return new Listings($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Listings', 'Lavalite\Listings\Facades\Listings');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.listings', function ($app) {
            return $this->app->make('Bixo\Listings\Listings');
        });

        // Bind Listing to repository
        $this->app->bind(
            'Bixo\Listings\Interfaces\ListingRepositoryInterface',
            \Bixo\Listings\Repositories\Eloquent\ListingRepository::class
        );
        // Bind Company to repository
        $this->app->bind(
            'Bixo\Listings\Interfaces\CompanyRepositoryInterface',
            \Bixo\Listings\Repositories\Eloquent\CompanyRepository::class
        );

        $this->app->register(\Bixo\Listings\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\Listings\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and listings's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.listings'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeListings::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.listings'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/listings.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/listings')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/listings')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
